FlutterRouteConstructor class
The constructor or static method to use to create a page route The arguments will be used to generate the goTo method
Set the routeName to specify for which method this constructor should be used
Constructors
- FlutterRouteConstructor({String? routeName})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeName → String?
-
Set for which routeName this constructor should be used
If not set, the constructor will be used for all routes
that don't have a constructor with a routeName set
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited